package be.iminds.ilabt.jfed.testing.tests.highlevel;

import be.iminds.ilabt.jfed.testing.base.ApiTestConfig;
import be.iminds.ilabt.jfed.testing.base.ApiTestConfigProperty;
import be.iminds.ilabt.jfed.testing.base.ApiTestConfigPropertyDefault;
import com.fasterxml.jackson.annotation.*;
import com.fasterxml.jackson.core.JsonProcessingException;
import com.fasterxml.jackson.databind.ObjectMapper;
import io.dropwizard.jackson.Jackson;

import javax.annotation.Nonnull;
import javax.annotation.Nullable;
import java.util.Objects;

@JsonInclude(JsonInclude.Include.NON_NULL)
@JsonIgnoreProperties(value={"@context"})
public class GuiLogicTestConfig implements ApiTestConfig {
    private static final ObjectMapper MAPPER = Jackson.newObjectMapper();

    private final Boolean skipFinalManifestCheck;

    @JsonCreator
    public GuiLogicTestConfig(@Nullable @JsonProperty("skipFinalManifestCheck") Boolean skipFinalManifestCheck) {
        this.skipFinalManifestCheck = skipFinalManifestCheck;
    }

    @JsonProperty
    @ApiTestConfigProperty(description="Skip the detailed manifest test in the \"checkManifest\" step? If skipped, very basic testing of the manifest is still done.")
    @ApiTestConfigPropertyDefault(booleanValue = false)
    @Nullable
    public Boolean getSkipFinalManifestCheck() {
        return skipFinalManifestCheck;
    }

    @JsonIgnore
    public boolean getSkipFinalManifestCheckOrDefault() {
        return Objects.equals(skipFinalManifestCheck, Boolean.TRUE);
    }

    @Override
    @JsonIgnore
    public boolean isValid() {
        return true; //TODO
    }

    @Nonnull
    @Override
    @JsonIgnore
    public String stringValue() {
        try {
            return MAPPER.writeValueAsString(this);
        } catch (JsonProcessingException e) {
            throw new RuntimeException("Failed to covert "+getClass().getName()+" to String", e);
        }
    }
}
